@@ -76,15 +76,29 @@ enum
     LIST_FILE_NAME,
     LIST_FILE_POINTER,
     LIST_FILE_KEY,
-    LIST_FILE_OTHERDIR,
+    LIST_FILE_OTHERDIR, // To change color for other directories
     LIST_FONT_WEIGHT,
     LIST_ROW_BACKGROUND,
     LIST_ROW_FOREGROUND,
+    // Tag fields
+    LIST_FILE_TITLE,
+    LIST_FILE_ARTIST,
+    LIST_FILE_ALBUM,
+    LIST_FILE_YEAR,
+    LIST_FILE_TRACK,
+    LIST_FILE_GENRE,
+    LIST_FILE_COMMENT,
+    LIST_FILE_COMPOSER,
+    LIST_FILE_ORIG_ARTIST,
+    LIST_FILE_COPYRIGHT,
+    LIST_FILE_URL,
+    LIST_FILE_ENCODED_BY,
     LIST_COLUMN_COUNT
 };
 
 enum
 {
+    ARTIST_PIXBUF,
     ARTIST_NAME,
     ARTIST_NUM_ALBUMS,
     ARTIST_NUM_FILES,
@@ -97,6 +111,7 @@ enum
 
 enum
 {
+    ALBUM_PIXBUF,
     ALBUM_NAME,
     ALBUM_NUM_FILES,
     ALBUM_ETFILE_LIST_POINTER,
