@@ -79,8 +79,8 @@ static int    libid3tag_Get_Frame_Str   (const struct id3_frame *frame, unsigned
 
 static void   Id3tag_delete_frames      (struct id3_tag *tag, const gchar *name, int start);
 static void   Id3tag_delete_txxframes   (struct id3_tag *tag, const gchar *param1, int start);
-static struct id3_frame *Id3tag_findncreate_frame     (struct id3_tag *tag, const gchar *name);
-static struct id3_frame *Id3tag_findncreate_txxframe  (struct id3_tag *tag, const gchar *param1);
+static struct id3_frame *Id3tag_find_and_create_frame    (struct id3_tag *tag, const gchar *name);
+static struct id3_frame *Id3tag_find_and_create_txxframe (struct id3_tag *tag, const gchar *param1);
 static int    id3taglib_set_field       (struct id3_frame *frame, const gchar *str, enum id3_field_type type, int num, int clear, int id3v1);
 static int    etag_set_tags             (const gchar *str, const char *frame_name, enum id3_field_type field_type, struct id3_tag *v1tag, struct id3_tag *v2tag, gboolean *strip_tags);
 static int    etag_write_tags           (const gchar *filename, const struct id3_tag *v1tag, const struct id3_tag *v2tag, gboolean strip_tags);
@@ -143,6 +143,7 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         /* ID3v2 tag found */
         if (FILE_WRITING_ID3V2_WRITE_TAG == 0)
         {
+            // To delete the tag
             update = 1;
         }else
         {
@@ -359,21 +360,24 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     if ( (frame = id3_tag_findframe(tag, "WXXX", 0)) )
         update |= libid3tag_Get_Frame_Str(frame, EASYTAG_ID3_FIELD_LATIN1, &FileTag->url);
 
-    /*********************
-     * Encoded by (TENC) *
-     *********************/
+    /*******************************
+     * Encoded by (TENC) or (TXXX) *
+     *******************************/
     if ( (frame = id3_tag_findframe(tag, "TENC", 0)) )
         update |= libid3tag_Get_Frame_Str(frame, ~0, &FileTag->encoded_by);
+    
     /* Encoded by in TXXX frames */
     string1 = NULL;
     for (i = 0; (frame = id3_tag_findframe(tag, "TXX", i)); i++)
     {
+        // Do nothing if already read...
         if (FileTag->encoded_by)
             break;
+        
         tmpupdate = libid3tag_Get_Frame_Str(frame, ~0, &string1);
         if (string1)
         {
-            if (strcasestr(string1, EASYTAG_STRING_ENCODEDBY MULTIFIELD_SEPARATOR) == string1)
+            if (strncasecmp(string1, EASYTAG_STRING_ENCODEDBY MULTIFIELD_SEPARATOR, strlen(EASYTAG_STRING_ENCODEDBY MULTIFIELD_SEPARATOR)) == 0)
             {
                 FileTag->encoded_by = g_strdup(&string1[sizeof(EASYTAG_STRING_ENCODEDBY) + sizeof(MULTIFIELD_SEPARATOR) - 2]);
                 g_free(string1);
@@ -411,7 +415,7 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                         data = id3_field_getbinarydata(field, &size);
                         if (pic->data)
                             g_free(pic->data);
-                        if ( (pic->data = g_memdup(data, size)) )
+                        if ( data && (pic->data = g_memdup(data, size)) )
                             pic->size = size;
                     }
                     break;
@@ -764,7 +768,6 @@ gboolean Id3tag_Write_File_v24Tag (ET_File *ETFile)
     union id3_field  *field;
     gchar            *string1;
     Picture          *pic;
-    unsigned          i;
     gint error = 0;
     gboolean strip_tags = TRUE;
     guchar genre_value = ID3_INVALID_GENRE;
@@ -783,7 +786,7 @@ gboolean Id3tag_Write_File_v24Tag (ET_File *ETFile)
     {
         struct id3_file *file;
         struct id3_tag *tmptag;
-        unsigned i;
+        unsigned tagsize;
         id3_byte_t *tmpbuf = NULL;
 
         /* Read old v2 tag */
@@ -803,12 +806,12 @@ gboolean Id3tag_Write_File_v24Tag (ET_File *ETFile)
             ID3_TAG_OPTION_UNSYNCHRONISATION);
 
         /* XXX Create new tag and copy all frames*/
-        i = id3_tag_render(tmptag, NULL);
-        if ((i > 10)
-        && (tmpbuf = g_try_malloc(i))
+        tagsize = id3_tag_render(tmptag, NULL);
+        if ((tagsize > 10)
+        && (tmpbuf = g_try_malloc(tagsize))
         && (id3_tag_render(tmptag, tmpbuf) != 0)
         )
-            v2tag = id3_tag_parse(tmpbuf, i);
+            v2tag = id3_tag_parse(tmpbuf, tagsize);
         g_free(tmpbuf);
 
         if (v2tag == NULL)
@@ -824,7 +827,7 @@ gboolean Id3tag_Write_File_v24Tag (ET_File *ETFile)
 
         /* Set padding  XXX */
         if ((v2tag->paddedsize < 1024)
-        || ((v2tag->paddedsize > 4096) && (i < 1024))
+        || ((v2tag->paddedsize > 4096) && (tagsize < 1024))
         )
             v2tag->paddedsize = 1024;
 
@@ -937,13 +940,15 @@ gboolean Id3tag_Write_File_v24Tag (ET_File *ETFile)
     /***************
      * Encoded by  *
      ***************/
-    if ( v2tag && FileTag->encoded_by && *FileTag->encoded_by
-    && (frame = Id3tag_findncreate_txxframe(v2tag, EASYTAG_STRING_ENCODEDBY)))
-    {
-        id3taglib_set_field(frame, EASYTAG_STRING_ENCODEDBY, ID3_FIELD_TYPE_STRING, 0, 1, 0);
-        id3taglib_set_field(frame, FileTag->encoded_by, ID3_FIELD_TYPE_STRING, 1, 0, 0);
-        strip_tags = FALSE;
-    }else
+    //if ( v2tag && FileTag->encoded_by && *FileTag->encoded_by
+    //&& (frame = Id3tag_find_and_create_txxframe(v2tag, EASYTAG_STRING_ENCODEDBY)))
+    //{
+    //    id3taglib_set_field(frame, EASYTAG_STRING_ENCODEDBY, ID3_FIELD_TYPE_STRING, 0, 1, 0);
+    //    id3taglib_set_field(frame, FileTag->encoded_by, ID3_FIELD_TYPE_STRING, 1, 0, 0);
+    //    strip_tags = FALSE;
+    //}else
+    // Save encoder name in TENC frame instead of the TXX frame
+    etag_set_tags(FileTag->encoded_by, "TENC", ID3_FIELD_TYPE_STRINGLIST, NULL, v2tag, &strip_tags);
     if (v2tag)
         Id3tag_delete_txxframes(v2tag, EASYTAG_STRING_ENCODEDBY, 0);
 
@@ -958,26 +963,21 @@ gboolean Id3tag_Write_File_v24Tag (ET_File *ETFile)
     {
         while (pic)
         {
+            gint i;
+
             if ((frame = id3_frame_new("APIC")) == NULL)
                 continue;
 
             id3_tag_attachframe(v2tag, frame);
             for (i = 0; (field = id3_frame_field(frame, i)); i++)
             {
+                Picture_Format format;
+                
                 switch (id3_field_type(field))
                 {
                     case ID3_FIELD_TYPE_LATIN1:
-                        switch (Picture_Format(pic))
-                        {
-                            case PICTURE_FORMAT_JPEG:
-                                id3_field_setlatin1(field, (id3_latin1_t const *)"image/jpeg");
-                                break;
-                            case PICTURE_FORMAT_PNG:
-                                id3_field_setlatin1(field, (id3_latin1_t const *)"image/png");
-                                break;
-                            default:
-                                break;
-                        }
+                        format = Picture_Format_From_Data(pic);
+                        id3_field_setlatin1(field, (id3_latin1_t const *)Picture_Mime_Type_String(format));
                         break;
                     case ID3_FIELD_TYPE_INT8:
                         id3_field_setint(field, pic->type);
@@ -1007,6 +1007,7 @@ gboolean Id3tag_Write_File_v24Tag (ET_File *ETFile)
      *********************************/
     error |= etag_write_tags(filename, v1tag, v2tag, strip_tags);
 
+    // Free data
     if (v1tag)
         id3_tag_delete(v1tag);
     if (v2tag)
@@ -1015,7 +1016,7 @@ gboolean Id3tag_Write_File_v24Tag (ET_File *ETFile)
     if (error == 0)
     {
         basename_utf8 = g_path_get_basename(filename_utf8);
-        Log_Print(_("Updated tag of '%s'"),basename_utf8);
+        Log_Print(LOG_OK,_("Updated tag of '%s'"),basename_utf8);
         g_free(basename_utf8);
     }
 
@@ -1062,7 +1063,7 @@ Id3tag_delete_txxframes(struct id3_tag *tag, const gchar *param1, int start)
         {
             str = NULL;
             if ((str = (gchar *)id3_ucs4_latin1duplicate(ucs4string))
-            && (strcasestr(str, param1) == str) )
+            && (strncasecmp(str, param1, strlen(param1)) == 0) )
             {
                 g_free(str);
                 id3_tag_detachframe(tag, frame);
@@ -1080,7 +1081,7 @@ Id3tag_delete_txxframes(struct id3_tag *tag, const gchar *param1, int start)
  * create new if not found
  */
 static struct id3_frame *
-Id3tag_findncreate_frame(struct id3_tag *tag, const gchar *name)
+Id3tag_find_and_create_frame (struct id3_tag *tag, const gchar *name)
 {
     struct id3_frame *frame;
 
@@ -1103,7 +1104,7 @@ Id3tag_findncreate_frame(struct id3_tag *tag, const gchar *name)
  * create new if not found
  */
 static struct id3_frame *
-Id3tag_findncreate_txxframe(struct id3_tag *tag, const gchar *param1)
+Id3tag_find_and_create_txxframe (struct id3_tag *tag, const gchar *param1)
 {
     const id3_ucs4_t *ucs4string;
     struct id3_frame *frame;
@@ -1120,7 +1121,7 @@ Id3tag_findncreate_txxframe(struct id3_tag *tag, const gchar *param1)
     {
         str = NULL;
         if ((str = (gchar *)id3_ucs4_latin1duplicate(ucs4string))
-        && (strcasestr(str, param1) == str) )
+        && (strncasecmp(str, param1, strlen(param1)) == 0) )
         {
             g_free(str);
             break;
@@ -1139,9 +1140,10 @@ Id3tag_findncreate_txxframe(struct id3_tag *tag, const gchar *param1)
 }
 
 static int
-id3taglib_set_field(struct id3_frame *frame, const gchar *str,
-    enum id3_field_type type,
-    int num, int clear, int id3v1)
+id3taglib_set_field(struct id3_frame *frame,
+                    const gchar *str,
+                    enum id3_field_type type,
+                    int num, int clear, int id3v1)
 {
     union id3_field    *field;
     enum id3_field_type    curtype;
@@ -1306,12 +1308,12 @@ id3taglib_set_field(struct id3_frame *frame, const gchar *str,
 
 
 static int
-etag_set_tags(const gchar *str,
-    const char *frame_name,
-    enum id3_field_type field_type,
-    struct id3_tag *v1tag,
-    struct id3_tag *v2tag,
-    gboolean *strip_tags)
+etag_set_tags (const gchar *str,
+               const char *frame_name,
+               enum id3_field_type field_type,
+               struct id3_tag *v1tag,
+               struct id3_tag *v2tag,
+              gboolean *strip_tags)
 {
     struct id3_frame *ftmp;
 
@@ -1320,10 +1322,10 @@ etag_set_tags(const gchar *str,
         *strip_tags = FALSE;
 
         if (v2tag
-        && (ftmp = Id3tag_findncreate_frame(v2tag, frame_name)))
+        && (ftmp = Id3tag_find_and_create_frame(v2tag, frame_name)))
             id3taglib_set_field(ftmp, str, field_type, 0, 1, 0);
         if (v1tag
-        && (ftmp = Id3tag_findncreate_frame(v1tag, frame_name)))
+        && (ftmp = Id3tag_find_and_create_frame(v1tag, frame_name)))
             id3taglib_set_field(ftmp, str, field_type, 0, 1, 1);
     }else
         if (v2tag)
@@ -1333,7 +1335,10 @@ etag_set_tags(const gchar *str,
 }
 
 static int
-etag_write_tags(const gchar *filename, const struct id3_tag *v1tag, const struct id3_tag *v2tag, gboolean strip_tags)
+etag_write_tags (const gchar *filename, 
+                 const struct id3_tag *v1tag, 
+                 const struct id3_tag *v2tag, 
+                 gboolean strip_tags)
 {
     id3_byte_t *v1buf, *v2buf;
     id3_length_t v1size = 0, v2size = 0;
@@ -1395,38 +1400,42 @@ etag_write_tags(const gchar *filename, const struct id3_tag *v1tag, const struct
     err = 1;
 
     /* Handle Id3v1 tag */
-    if (lseek(fd, -128, SEEK_END) < 0)
+    if ((curpos = lseek(fd, -128, SEEK_END)) < 0)
         goto out;
     if (read(fd, tmp, ID3_TAG_QUERYSIZE) != ID3_TAG_QUERYSIZE)
         goto out;
 
     if ( (tmp[0] == 'T')
-    && (tmp[1] == 'A')
-    && (tmp[2] == 'G')
+    &&   (tmp[1] == 'A')
+    &&   (tmp[2] == 'G')
        )
     {
-        if (lseek(fd, -128, SEEK_END) < 0)
+        if ((curpos = lseek(fd, -128, SEEK_END)) < 0)
+        {
             goto out;
+        }
     }else
-        if (lseek(fd, 0, SEEK_END) < 0)
+        if ((curpos = lseek(fd, 0, SEEK_END)) < 0)
+        {
             goto out;
+        }
 
     /* Search id3v2 tags at the end of the file (before any ID3v1 tag) */
     /* XXX: Unsafe */
-    if (lseek(fd, -ID3_TAG_QUERYSIZE, SEEK_CUR) >= 0)
+    if ((curpos = lseek(fd, -ID3_TAG_QUERYSIZE, SEEK_CUR)) >= 0)
     {
         if (read(fd, tmp, ID3_TAG_QUERYSIZE) != ID3_TAG_QUERYSIZE)
             goto out;
         filev2size = id3_tag_query((id3_byte_t const *)tmp, ID3_TAG_QUERYSIZE);
-        if ((filev2size > 10)
-        && lseek(fd, -filev2size, SEEK_CUR))
+        if ( (filev2size > 10)
+        &&   (curpos = lseek(fd, -filev2size, SEEK_CUR)) )
         {
             if (read(fd, tmp, ID3_TAG_QUERYSIZE) != ID3_TAG_QUERYSIZE)
                 goto out;
             if (id3_tag_query((id3_byte_t const *)tmp, ID3_TAG_QUERYSIZE) != filev2size)
-                lseek(fd, -ID3_TAG_QUERYSIZE - filev2size, SEEK_CUR);
+                curpos = lseek(fd, -ID3_TAG_QUERYSIZE - filev2size, SEEK_CUR);
             else
-                lseek(fd, -ID3_TAG_QUERYSIZE, SEEK_CUR);
+                curpos = lseek(fd, -ID3_TAG_QUERYSIZE, SEEK_CUR);
         }
     }
 
@@ -1442,7 +1451,7 @@ etag_write_tags(const gchar *filename, const struct id3_tag *v1tag, const struct
         goto out;
 
     /* Handle Id3v2 tag */
-    if (lseek(fd, 0, SEEK_SET) < 0)
+    if ((curpos = lseek(fd, 0, SEEK_SET)) < 0)
         goto out;
 
     if (read(fd, tmp, ID3_TAG_QUERYSIZE) != ID3_TAG_QUERYSIZE)
@@ -1456,35 +1465,35 @@ etag_write_tags(const gchar *filename, const struct id3_tag *v1tag, const struct
 
     if (filev2size == v2size)
     {
-        if (lseek(fd, 0, SEEK_SET) < 0)
+        if ((curpos = lseek(fd, 0, SEEK_SET)) < 0)
             goto out;
         if (write(fd, v2buf, v2size) != v2size)
             goto out;
     }else
     {
-    /* XXX */
-    ctxsize = lseek(fd, 0, SEEK_END) - filev2size;
-    if ((ctx = g_try_malloc(ctxsize)) == NULL)
-        goto out;
-    if (lseek(fd, filev2size, SEEK_SET) < 0)
-        goto out;
-    if (read(fd, ctx, ctxsize) != ctxsize)
-        goto out;
-    if (lseek(fd, 0, SEEK_SET) < 0)
-        goto out;
-    if (v2buf)
-        write(fd, v2buf, v2size);
+        /* XXX */
+        ctxsize = lseek(fd, 0, SEEK_END) - filev2size;
+        if ((ctx = g_try_malloc(ctxsize)) == NULL)
+            goto out;
+        if (lseek(fd, filev2size, SEEK_SET) < 0)
+            goto out;
+        if (read(fd, ctx, ctxsize) != ctxsize)
+            goto out;
+        if (lseek(fd, 0, SEEK_SET) < 0)
+            goto out;
+        if (v2buf)
+            write(fd, v2buf, v2size);
 
-    if (write(fd, ctx, ctxsize) != ctxsize)
-    {
-        g_print("OOPS\n");
-        goto out;
-    }
+        if (write(fd, ctx, ctxsize) != ctxsize)
+        {
+            g_print("OOPS\n");
+            goto out;
+        }
 
-    if ((curpos = lseek(fd, 0, SEEK_CUR)) <= 0 )
-        goto out;
-    if ((err = ftruncate(fd, curpos)))
-        goto out;
+        if ((curpos = lseek(fd, 0, SEEK_CUR)) <= 0 )
+            goto out;
+        if ((err = ftruncate(fd, curpos)))
+            goto out;
     }
 
     err = 0;
