@@ -191,7 +191,7 @@ void Open_OptionsWindow (void)
     g_free(path_utf8);
 
     // Button browse
-    Button = Create_Button_With_Pixmap(BUTTON_BROWSE);
+    Button = gtk_button_new_from_stock(GTK_STOCK_OPEN);
     gtk_box_pack_start(GTK_BOX(HBox),Button,FALSE,FALSE,0);
     g_signal_connect_swapped(G_OBJECT(Button),"clicked",
                              G_CALLBACK(File_Selection_Window_For_Directory),G_OBJECT(GTK_BIN(DefaultPathToMp3)->child));
@@ -402,11 +402,43 @@ void Open_OptionsWindow (void)
     g_free(program_path);
 
     // Button browse
-    Button = Create_Button_With_Pixmap(BUTTON_BROWSE);
+    Button = gtk_button_new_from_stock(GTK_STOCK_OPEN);
     gtk_box_pack_start(GTK_BOX(hbox),Button,FALSE,FALSE,0);
     g_signal_connect_swapped(G_OBJECT(Button),"clicked",
         G_CALLBACK(File_Selection_Window_For_File), G_OBJECT(GTK_BIN(FilePlayerCombo)->child));
 
+    /* Log options */
+    Frame = gtk_frame_new (_("Log Options"));
+    gtk_box_pack_start(GTK_BOX(VBox),Frame,FALSE,FALSE,0);
+    vbox = gtk_vbox_new(FALSE,2);
+    gtk_container_add(GTK_CONTAINER(Frame),vbox);
+    gtk_container_set_border_width(GTK_CONTAINER(vbox), 2);
+
+    // Show / hide log view
+    ShowLogView = gtk_check_button_new_with_label(_("Show log view in main window"));
+    gtk_box_pack_start(GTK_BOX(vbox),ShowLogView,FALSE,FALSE,0);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ShowLogView),SHOW_LOG_VIEW);
+    gtk_tooltips_set_tip(Tips,ShowLogView,_("If activated, the log view would be "
+                                            "visible in the main window."),NULL);
+   
+    // Max number of lines
+    hbox = gtk_hbox_new(FALSE,2);
+    gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
+    gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
+    Label = gtk_label_new (_("Max number of lines :"));
+    gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,0);
+    
+    LogMaxLinesSpinButton = gtk_spin_button_new((GtkAdjustment *)gtk_adjustment_new(2.0,2.0,6.0,1.0,1.0,1.0),1.0,0);
+    LogMaxLinesSpinButton = gtk_spin_button_new_with_range(10.0,1500.0,10.0);
+    gtk_box_pack_start(GTK_BOX(hbox),LogMaxLinesSpinButton,FALSE,FALSE,0);
+    gtk_spin_button_set_value(GTK_SPIN_BUTTON(LogMaxLinesSpinButton),(gfloat)LOG_MAX_LINES);
+    //g_signal_connect(G_OBJECT(NumberTrackFormated),"toggled",G_CALLBACK(Number_Track_Formated_Toggled),NULL);
+    //g_signal_emit_by_name(G_OBJECT(NumberTrackFormated),"toggled");
+/*    gtk_tooltips_set_tip(Tips,GTK_BIN(FilePlayerCombo)->child,_("Enter the program used to "
+        "play the files. Some arguments can be passed for the program (as 'xmms -p') before "
+        "to receive files as other arguments."),NULL);
+*/
+
 
 
     /*
@@ -787,9 +819,13 @@ void Open_OptionsWindow (void)
     gtk_table_attach(GTK_TABLE(Table),LabelAdditionalId3v2IconvOptions,2,5,5,6,GTK_FILL,GTK_FILL,0,0);
     gtk_misc_set_alignment(GTK_MISC(LabelAdditionalId3v2IconvOptions),0,0.5);
 
-    FileWritingId3v2IconvOptionsNo = gtk_radio_button_new_with_label(NULL, _("No"));
+    FileWritingId3v2IconvOptionsNo = gtk_radio_button_new_with_label(NULL,
+        _("No"));
     gtk_table_attach(GTK_TABLE(Table),FileWritingId3v2IconvOptionsNo,2,3,6,7,GTK_FILL,GTK_FILL,0,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(FileWritingId3v2IconvOptionsNo),FILE_WRITING_ID3V2_ICONV_OPTIONS_NO);
+    gtk_tooltips_set_tip(Tips,FileWritingId3v2IconvOptionsNo,_("With this option, when "
+        "a character cannot be represented in the target character set, it isn't changed. "
+        "But note that an error message will be displayed for information."),NULL);
     FileWritingId3v2IconvOptionsTranslit = gtk_radio_button_new_with_label(
         gtk_radio_button_get_group(GTK_RADIO_BUTTON(FileWritingId3v2IconvOptionsNo)),
         _("//TRANSLIT"));
@@ -856,6 +892,9 @@ void Open_OptionsWindow (void)
         _("No"));
     gtk_table_attach(GTK_TABLE(Table),FileWritingId3v1IconvOptionsNo,1,2,4,5,GTK_FILL,GTK_FILL,0,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(FileWritingId3v1IconvOptionsNo),FILE_WRITING_ID3V1_ICONV_OPTIONS_NO);
+    gtk_tooltips_set_tip(Tips,FileWritingId3v1IconvOptionsNo,_("With this option, when "
+        "a character cannot be represented in the target character set, it isn't changed. "
+        "But note that an error message will be displayed for information."),NULL);
     FileWritingId3v1IconvOptionsTranslit = gtk_radio_button_new_with_label(
         gtk_radio_button_get_group(GTK_RADIO_BUTTON(FileWritingId3v1IconvOptionsNo)),
         _("//TRANSLIT"));
@@ -883,6 +922,7 @@ void Open_OptionsWindow (void)
 
     Table = gtk_table_new(4,2,FALSE);
     gtk_box_pack_start(GTK_BOX(vbox),Table,FALSE,FALSE,0);
+    //gtk_container_set_border_width(GTK_CONTAINER(Table), 2);
     //gtk_table_set_row_spacings(GTK_TABLE(Table),2);
     gtk_table_set_col_spacings(GTK_TABLE(Table),2);
 
@@ -1137,7 +1177,7 @@ void Open_OptionsWindow (void)
     CddbServerCgiPathAutomaticSearch = gtk_entry_new();
     gtk_box_pack_start(GTK_BOX(hbox),CddbServerCgiPathAutomaticSearch,FALSE,FALSE,0);
     if (CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH)
-        gtk_entry_set_text(GTK_ENTRY(CddbServerCgiPathAutomaticSearch) ,CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH);
+        gtk_entry_set_text(GTK_ENTRY(CddbServerCgiPathAutomaticSearch),CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH);
 
     // 2sd automatic search server
     hbox = gtk_hbox_new(FALSE,2);
@@ -1242,7 +1282,7 @@ void Open_OptionsWindow (void)
         g_free(path_utf8);
     }
 
-    Button = Create_Button_With_Pixmap(BUTTON_BROWSE);
+    Button = gtk_button_new_from_stock(GTK_STOCK_OPEN);
     gtk_box_pack_start(GTK_BOX(hbox),Button,FALSE,FALSE,0);
     g_signal_connect_swapped(G_OBJECT(Button),"clicked",
                              G_CALLBACK(File_Selection_Window_For_Directory),G_OBJECT(GTK_BIN(CddbLocalPath)->child));
@@ -1381,25 +1421,25 @@ void Open_OptionsWindow (void)
 
 
     /* Apply Button */
-    Button = Create_Button_With_Pixmap(BUTTON_APPLY);
+    Button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
     // Disable temporarily the apply button
     ////gtk_container_add(GTK_CONTAINER(ButtonBox),Button);
-    g_signal_connect(G_OBJECT(Button),"clicked",G_CALLBACK(OptionsWindow_Apply_Button),NULL);
-    GTK_WIDGET_SET_FLAGS(Button, GTK_CAN_DEFAULT);
+    ////g_signal_connect(G_OBJECT(Button),"clicked",G_CALLBACK(OptionsWindow_Apply_Button),NULL);
+    ////GTK_WIDGET_SET_FLAGS(Button, GTK_CAN_DEFAULT);
     gtk_tooltips_set_tip(Tips,Button,_("Apply changes (but don't save) and close this window"),NULL);
 
 
     /* Cancel Button */
-    Button = Create_Button_With_Pixmap(BUTTON_CANCEL);
+    Button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
     gtk_container_add(GTK_CONTAINER(ButtonBox), Button);
     g_signal_connect(G_OBJECT(Button),"clicked", G_CALLBACK(OptionsWindow_Cancel_Button),NULL);
     GTK_WIDGET_SET_FLAGS(Button, GTK_CAN_DEFAULT);
-    gtk_widget_grab_default (Button);
+    gtk_widget_grab_default(Button);
     gtk_tooltips_set_tip(Tips,Button,_("Close this window without saving"),NULL);
 
 
     /* Save Button */
-    Button = Create_Button_With_Pixmap(BUTTON_SAVE);
+    Button = gtk_button_new_from_stock(GTK_STOCK_OK);
     gtk_container_add(GTK_CONTAINER(ButtonBox), Button);
     g_signal_connect(G_OBJECT(Button),"clicked", G_CALLBACK(OptionsWindow_Save_Button),NULL);
     GTK_WIDGET_SET_FLAGS(Button, GTK_CAN_DEFAULT);
@@ -1616,12 +1656,6 @@ void OptionsWindow_Quit(void)
 {
     if (OptionsWindow)
     {
-        /* Save combobox history lists before exit */
-        Save_Default_Path_To_MP3_List     (DefaultPathModel, MISC_COMBO_TEXT);
-        Save_Default_Tag_Comment_Text_List(DefaultCommentModel, MISC_COMBO_TEXT);
-        Save_Audio_File_Player_List       (FilePlayerModel, MISC_COMBO_TEXT);
-        Save_Cddb_Local_Path_List         (CddbLocalPathModel, MISC_COMBO_TEXT);
-
         OptionsWindow_Apply_Changes();
 
         /* Now quit */
@@ -1655,6 +1689,12 @@ void OptionsWindow_Apply_Changes (void)
 
         /* Get the last visible notebook page */
         OPTIONS_NOTEBOOK_PAGE = gtk_notebook_get_current_page(GTK_NOTEBOOK(OptionsNoteBook));
+
+        /* Save combobox history lists before exit */
+        Save_Default_Path_To_MP3_List     (DefaultPathModel, MISC_COMBO_TEXT);
+        Save_Default_Tag_Comment_Text_List(DefaultCommentModel, MISC_COMBO_TEXT);
+        Save_Audio_File_Player_List       (FilePlayerModel, MISC_COMBO_TEXT);
+        Save_Cddb_Local_Path_List         (CddbLocalPathModel, MISC_COMBO_TEXT);
     }
 }
 
@@ -1703,10 +1743,15 @@ gint Check_DefaultPathToMp3 (void)
         gchar *msg = g_strdup_printf(_(" The selected path for 'Default path to "
             "files' isn't valid!\n'%s'\n(%s) "),path_utf8,
             (stat(path_real,&stbuf)==0)?_("Not a directory"):g_strerror(errno) );
-        GtkWidget *msgbox = msg_box_new(_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
-        msg_box_hide_check_button(MSG_BOX(msgbox));
-        gtk_window_set_transient_for(GTK_WINDOW(msgbox),GTK_WINDOW(OptionsWindow));
-        msg_box_run(MSG_BOX(msgbox));
+        GtkWidget *msgbox = msg_box_new(_("Error..."),
+                                        GTK_WINDOW(OptionsWindow),
+                                        NULL,
+                                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                        msg,
+                                        GTK_STOCK_DIALOG_ERROR,
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                        NULL);
+        gtk_dialog_run(GTK_DIALOG(msgbox));
         gtk_widget_destroy(msgbox);
         g_free(msg);
         g_free(path_real);
@@ -1741,10 +1786,15 @@ gint Check_CharacterSetTranslation (void)
     {
         gchar *msg = g_strdup_printf(_("The character set translation from '%s'\n"
                                        "to '%s' isn't supported!"),reading_character,"UTF-8");
-        GtkWidget *msgbox = msg_box_new(_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
-        msg_box_hide_check_button(MSG_BOX(msgbox));
-        gtk_window_set_transient_for(GTK_WINDOW(msgbox),GTK_WINDOW(OptionsWindow));
-        msg_box_run(MSG_BOX(msgbox));
+        GtkWidget *msgbox = msg_box_new(_("Error..."),
+                                        GTK_WINDOW(OptionsWindow),
+                                        NULL,
+                                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                        msg,
+                                        GTK_STOCK_DIALOG_ERROR,
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                        NULL);
+        gtk_dialog_run(GTK_DIALOG(msgbox));
         gtk_widget_destroy(msgbox);
         g_free(msg);
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(UseNonStandardId3ReadingCharacterSet),FALSE);
@@ -1756,10 +1806,15 @@ gint Check_CharacterSetTranslation (void)
     {
         gchar *msg = g_strdup_printf(_("The character set translation from '%s'\n"
                                        "to '%s' isn't supported!"),"UTF-8",writing_character);
-        GtkWidget *msgbox = msg_box_new(_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
-        msg_box_hide_check_button(MSG_BOX(msgbox));
-        gtk_window_set_transient_for(GTK_WINDOW(msgbox),GTK_WINDOW(OptionsWindow));
-        msg_box_run(MSG_BOX(msgbox));
+        GtkWidget *msgbox = msg_box_new(_("Error..."),
+                                        GTK_WINDOW(OptionsWindow),
+                                        NULL,
+                                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                        msg,
+                                        GTK_STOCK_DIALOG_ERROR,
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                        NULL);
+        gtk_dialog_run(GTK_DIALOG(msgbox));
         gtk_widget_destroy(msgbox);
         g_free(msg);
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(UseNonStandardId3WritingCharacterSet),FALSE);
@@ -1805,10 +1860,15 @@ gint Check_FilePlayerCombo (void)
     {
         gchar *msg = g_strdup_printf(_("The audio file player '%s' can't be found!"),
             gtk_entry_get_text(GTK_ENTRY(GTK_BIN(FilePlayerCombo)->child)));
-        GtkWidget *msgbox = msg_box_new(_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
-        msg_box_hide_check_button(MSG_BOX(msgbox));
-        gtk_window_set_transient_for(GTK_WINDOW(msgbox),GTK_WINDOW(OptionsWindow));
-        msg_box_run(MSG_BOX(msgbox));
+        GtkWidget *msgbox = msg_box_new(_("Error..."),
+                                        GTK_WINDOW(OptionsWindow),
+                                        NULL,
+                                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                        msg,
+                                        GTK_STOCK_DIALOG_ERROR,
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                        NULL);
+        gtk_dialog_run(GTK_DIALOG(msgbox));
         gtk_widget_destroy(msgbox);
         g_free(msg);
 
