@@ -39,6 +39,12 @@ enum
     SCANNER_PROCESS_FIELDS
 }; // Add a new item : Min and Max values used in Open_ScannerWindow
 
+enum {
+    MASK_EDITOR_TEXT,
+    MASK_EDITOR_COUNT
+};
+
+
 
 /**************
  * Prototypes *
@@ -48,31 +54,35 @@ void   Scan_Tag_With_Mask                   (ET_File *ETFile);
 void   Scan_Rename_File_With_Mask           (ET_File *ETFile);
 void   Scan_Process_Fields                  (ET_File *ETFile);
 void   Scan_Select_Mode_And_Run_Scanner     (ET_File *ETFile);
-gchar *Scan_Generate_New_Filename_From_Mask (ET_File *ETFile, gchar *mask);
-GList *Scan_Generate_New_Tag_From_Mask      (ET_File *ETFile, gchar *mask);
-void   Scan_Rename_File_Generate_Preview    (void);
-void   Scan_Fill_Tag_Generate_Preview       (void);
+gchar *Scan_Generate_New_Filename_From_Mask       (ET_File *ETFile, gchar *mask, gboolean no_dir_check_or_conversion);
+GList *Scan_Generate_New_Tag_From_Mask            (ET_File *ETFile, gchar *mask);
+gchar *Scan_Generate_New_Directory_Name_From_Mask (ET_File *ETFile, gchar *mask, gboolean no_dir_check_or_conversion);
+void   Scan_Rename_File_Generate_Preview      (void);
+void   Scan_Fill_Tag_Generate_Preview         (void);
+void   Scan_Rename_Directory_Generate_Preview (void);
 
 void   Scan_Use_Fill_Tag_Scanner            (void);
 void   Scan_Use_Rename_File_Scanner         (void);
 void   Scan_Use_Process_Fields_Scanner      (void);
 
-void Scan_Process_Fields_All_Uppercase           (gchar *text);
-void Scan_Process_Fields_All_Downcase            (gchar *text);
-void Scan_Process_Fields_Letter_Uppercase        (gchar *text);
-void Scan_Process_Fields_First_Letters_Uppercase (gchar *text);
-void Scan_Process_Fields_Remove_Space            (gchar *text);
-void Scan_Process_Fields_Insert_Space            (gchar *text);
-void Scan_Process_Fields_Keep_One_Space          (gchar *text);
+gboolean Scan_Check_Rename_File_Mask (GtkObject *widget_to_show_hide, GtkEntry *widget_source);
+
+void Scan_Process_Fields_All_Uppercase           (gchar *string);
+void Scan_Process_Fields_All_Downcase            (gchar *string);
+void Scan_Process_Fields_Letter_Uppercase        (gchar *string);
+void Scan_Process_Fields_First_Letters_Uppercase (gchar *string);
+void Scan_Process_Fields_Remove_Space            (gchar *string);
+void Scan_Process_Fields_Insert_Space            (gchar **string);
+void Scan_Process_Fields_Keep_One_Space          (gchar *string);
 
 void Scan_Convert_Underscore_Into_Space (gchar *string);
 void Scan_Convert_P20_Into_Space        (gchar *string);
 void Scan_Convert_Space_Into_Undescore  (gchar *string);
-void Scan_Convert                       (gchar *string);
+void Scan_Convert_Character             (gchar **string);
 
 void Init_ScannerWindow (void);
 void Open_ScannerWindow (gint scanner_type);
-void Scan_Apply_Changes (void);
+void ScannerWindow_Apply_Changes (void);
 
 void Scan_Set_Scanner_Window_Init_Position (void);
 
