@@ -126,6 +126,8 @@ gint    NUMBER_TRACK_FORMATED_SPIN_BUTTON;
 gint    OGG_TAG_WRITE_XMMS_COMMENT;
 gint    SET_FOCUS_TO_SAME_TAG_FIELD;
 gint    SET_FOCUS_TO_FIRST_TAG_FIELD;
+gint    LOG_MAX_LINES;
+gint    SHOW_LOG_VIEW;
 
 
 /* Scanner */
@@ -139,7 +141,7 @@ gint    RFS_CONVERT_SPACE_INTO_UNDERSCORE;
 gint    PFS_DONT_UPPER_SOME_WORDS;
 gint    OVERWRITE_TAG_FIELD;
 gint    SET_DEFAULT_COMMENT;
-gchar   *DEFAULT_COMMENT;
+gchar  *DEFAULT_COMMENT;
 gint    SET_CRC32_COMMENT;
 gint    OPEN_SCANNER_WINDOW_ON_STARTUP;
 gint    SCANNER_WINDOW_ON_TOP;
@@ -166,6 +168,8 @@ gint    PROCESS_ORIG_ARTIST_FIELD;
 gint    PROCESS_COPYRIGHT_FIELD;
 gint    PROCESS_URL_FIELD;
 gint    PROCESS_ENCODED_BY_FIELD;
+gchar  *PROCESS_FIELDS_CONVERT_FROM;
+gchar  *PROCESS_FIELDS_CONVERT_TO;
 gint    PF_CONVERT_INTO_SPACE;
 gint    PF_CONVERT_SPACE;
 gint    PF_CONVERT;
