@@ -30,6 +30,7 @@ vcedit_state *vcedit_new_state(void)
 {
     vcedit_state *state = malloc(sizeof(vcedit_state));
     memset(state, 0, sizeof(vcedit_state));
+    state->oggtype = VCEDIT_IS_UNKNOWN;
 
     return state;
 }
@@ -69,7 +70,7 @@ static void vcedit_clear_internals(vcedit_state *state)
     if(state->bookbuf)
         free(state->bookbuf);
     if(state->vi) {
-       vorbis_info_clear(state->vi);
+        vorbis_info_clear(state->vi);
         free(state->vi);
     }
 
@@ -98,15 +99,20 @@ static void _v_writestring(oggpack_buffer *o,char *s, int len)
     }
 }
 
-static int _commentheader_out(vorbis_comment *vc, char *vendor, ogg_packet *op)
+static int _commentheader_out(vcedit_state *state, ogg_packet *op)
 {
+    vorbis_comment *vc = state->vc;
+    char           *vendor = state->vendor;
     oggpack_buffer opb;
 
     oggpack_writeinit(&opb);
 
-    /* preamble */
-    oggpack_write(&opb,0x03,8);
-    _v_writestring(&opb,"vorbis", 6);
+    if (state->oggtype == VCEDIT_IS_OGGVORBIS)
+    {
+        /* preamble */
+        oggpack_write(&opb,0x03,8);
+        _v_writestring(&opb,"vorbis", 6);
+    }
 
     /* vendor */
     oggpack_write(&opb,strlen(vendor),32);
@@ -120,7 +126,7 @@ static int _commentheader_out(vorbis_comment *vc, char *vendor, ogg_packet *op)
             if(vc->user_comments[i]){
                 oggpack_write(&opb,vc->comment_lengths[i],32);
                 _v_writestring(&opb,vc->user_comments[i],
-                        vc->comment_lengths[i]);
+                               vc->comment_lengths[i]);
             }else{
                 oggpack_write(&opb,0,32);
             }
@@ -135,6 +141,10 @@ static int _commentheader_out(vorbis_comment *vc, char *vendor, ogg_packet *op)
     op->b_o_s=0;
     op->e_o_s=0;
     op->granulepos=0;
+    if (state->oggtype == VCEDIT_IS_OGGVORBIS)
+    {
+        op->packetno = 1;
+    }
 
     oggpack_writeclear(&opb);
     return 0;
@@ -191,6 +201,50 @@ static int _fetch_next_packet(vcedit_state *s, ogg_packet *p, ogg_page *page)
     }
 }
 
+/*
+ * Next functions pulled straight from libvorbis,
+ */
+static void _v_readstring(oggpack_buffer *o,char *buf,int bytes){
+  while(bytes--){
+    *buf++=oggpack_read(o,8);
+  }
+}
+
+/*
+ * Next functions pulled straight from libvorbis, apart from one change
+ * - disabled the EOP check
+ */
+static int _speex_unpack_comment(vorbis_comment *vc,oggpack_buffer *opb)
+{
+    int i;
+    int vendorlen=oggpack_read(opb,32);
+    if (vendorlen<0) 
+        goto err_out;
+
+    vc->vendor=_ogg_calloc(vendorlen+1,1);
+    _v_readstring(opb,vc->vendor,vendorlen);
+
+    vc->comments=oggpack_read(opb,32);
+    if (vc->comments<0)
+        goto err_out;
+    vc->user_comments=_ogg_calloc(vc->comments+1,sizeof(*vc->user_comments));
+    vc->comment_lengths=_ogg_calloc(vc->comments+1, sizeof(*vc->comment_lengths));
+    for (i=0;i<vc->comments;i++){
+        int len=oggpack_read(opb,32);
+        if (len<0)
+            goto err_out;
+        vc->comment_lengths[i]=len;
+        vc->user_comments[i]=_ogg_calloc(len+1,1);
+        _v_readstring(opb,vc->user_comments[i],len);
+    }
+    //if(oggpack_read(opb,1)!=1)goto err_out; /* EOP check */
+    return(0);
+
+err_out:
+    vorbis_comment_clear(vc);
+    return(1);
+}
+
 int vcedit_open(vcedit_state *state, FILE *in)
 {
     return vcedit_open_callbacks(state, (void *)in,
@@ -205,9 +259,9 @@ int vcedit_open_callbacks(vcedit_state *state, void *in,
     int bytes,i;
     int chunks = 0;
     ogg_packet *header;
-    ogg_packet    header_main;
+    ogg_packet  header_main;
     ogg_packet  header_comments;
-    ogg_packet    header_codebooks;
+    ogg_packet  header_codebooks;
     ogg_page    og;
 
     state->in = in;
@@ -260,26 +314,59 @@ int vcedit_open_callbacks(vcedit_state *state, void *in,
         goto err;
     }
 
-    if(vorbis_synthesis_headerin(state->vi, state->vc, &header_main) < 0)
-    {
-        state->lasterror = _("Ogg bitstream does not contain vorbis data.");
-        goto err;
-    }
-
+    // We save the main header first, (it seems speex_packet_to_header munge's it??)
     state->mainlen = header_main.bytes;
     state->mainbuf = malloc(state->mainlen);
     memcpy(state->mainbuf, header_main.packet, header_main.bytes);
 
-    i = 0;
-    header = &header_comments;
-    while(i<2) {
-        while(i<2) {
+    state->oggtype = VCEDIT_IS_UNKNOWN;
+    int headerpackets = 0;
+    if(vorbis_synthesis_headerin(state->vi, state->vc, &header_main) == 0)
+    {
+        state->oggtype = VCEDIT_IS_OGGVORBIS;
+    }
+#ifdef ENABLE_SPEEX
+    else
+    {
+        // Done after "Ogg test" to avoid to display an error message in function
+        // speex_packet_to_header when the file is not Speex.
+        state->si = malloc(sizeof(SpeexHeader));
+        if((state->si = speex_packet_to_header((char*)(&header_main)->packet,(&header_main)->bytes)))
+            state->oggtype = VCEDIT_IS_SPEEX;
+    }
+#endif
+
+    if (state->oggtype == VCEDIT_IS_UNKNOWN)
+    {
+        state->lasterror = _("Ogg bitstream contains neither speex or vorbis data.");
+        goto err;
+    }
+
+    switch (state->oggtype)
+    {
+        case VCEDIT_IS_OGGVORBIS:
+            header = &header_comments;
+            headerpackets = 3;
+            break;
+#ifdef ENABLE_SPEEX
+        case VCEDIT_IS_SPEEX:
+            header = &header_comments;
+            headerpackets = 2 + state->si->extra_headers;
+            break;
+#endif
+    }
+    oggpack_buffer opb;
+    i = 1;
+    while(i<headerpackets)
+    {
+        while(i<headerpackets)
+        {
             int result = ogg_sync_pageout(state->oy, &og);
             if(result == 0) break; /* Too little data so far */
             else if(result == 1)
             {
                 ogg_stream_pagein(state->os, &og);
-                while(i<2)
+                while(i< headerpackets)
                 {
                     result = ogg_stream_packetout(state->os, header);
                     if(result == 0) break;
@@ -288,16 +375,39 @@ int vcedit_open_callbacks(vcedit_state *state, void *in,
                         state->lasterror = _("Corrupt secondary header.");
                         goto err;
                     }
-                    vorbis_synthesis_headerin(state->vi, state->vc, header);
-                    if(i==1)
+                    switch (state->oggtype)
                     {
-                        state->booklen = header->bytes;
-                        state->bookbuf = malloc(state->booklen);
-                        memcpy(state->bookbuf, header->packet,
-                                header->bytes);
+                        case VCEDIT_IS_OGGVORBIS:
+                            vorbis_synthesis_headerin(state->vi, state->vc, header);
+                            switch (i) 
+                            {
+                                // 0 packet was the vorbis header
+                                case 1:
+                                    header = &header_codebooks;
+                                    break;
+                                case 2:
+                                    state->booklen = header->bytes;
+                                    state->bookbuf = malloc(state->booklen);
+                                    memcpy(state->bookbuf, header->packet, 
+                                           header->bytes);
+                                    break;
+                            }
+                            break;
+                        case VCEDIT_IS_SPEEX:
+                            switch (i) 
+                            {
+                                // 0 packet was the speex header
+                                case 1:
+                                    oggpack_readinit(&opb,header->packet,header->bytes);
+                                    _speex_unpack_comment(state->vc,&opb);
+                                    break;
+                                default:
+                                    state->lasterror = _("Need to save extra headers - TODO!!");
+                                    goto err;
+                                    break;
+                            }
                     }
                     i++;
-                    header = &header_codebooks;
                 }
             }
         }
@@ -356,16 +466,13 @@ int vcedit_write(vcedit_state *state, void *out)
 
     ogg_stream_init(&streamout, state->serial);
 
-    _commentheader_out(state->vc, state->vendor, &header_comments);
-
-    /* 2002/10/22 - new code here for padded headers */
-    //header_comments.packet = realloc(header_comments.packet, header_comments.bytes + 1000);
-    //header_comments.bytes += 1000;
-    /* end of new code */
+    _commentheader_out(state, &header_comments);
 
     ogg_stream_packetin(&streamout, &header_main);
     ogg_stream_packetin(&streamout, &header_comments);
-    ogg_stream_packetin(&streamout, &header_codebooks);
+
+    if (state->oggtype != VCEDIT_IS_SPEEX)
+        ogg_stream_packetin(&streamout, &header_codebooks);
 
     while((result = ogg_stream_flush(&streamout, &ogout)))
     {
@@ -379,10 +486,6 @@ int vcedit_write(vcedit_state *state, void *out)
 
     while(_fetch_next_packet(state, &op, &ogin))
     {
-        int size;
-        size = _blocksize(state, &op);
-        granpos += size;
-
         if(needflush)
         {
             if(ogg_stream_flush(&streamout, &ogout))
@@ -410,25 +513,39 @@ int vcedit_write(vcedit_state *state, void *out)
 
         needflush=needout=0;
 
-        if(op.granulepos == -1)
+        if (state->oggtype == VCEDIT_IS_OGGVORBIS)
         {
-            op.granulepos = granpos;
-            ogg_stream_packetin(&streamout, &op);
+            int size;
+            size = _blocksize(state, &op);
+            granpos += size;
+
+            if(op.granulepos == -1)
+            {
+                op.granulepos = granpos;
+                ogg_stream_packetin(&streamout, &op);
+            }
+            else /* granulepos is set, validly. Use it, and force a flush to 
+                account for shortened blocks (vcut) when appropriate */ 
+            {
+                if(granpos > op.granulepos)
+                {
+                    granpos = op.granulepos;
+                    ogg_stream_packetin(&streamout, &op);
+                    needflush=1;
+                }
+                else 
+                {
+                    ogg_stream_packetin(&streamout, &op);
+                    needout=1;
+                }
+            }
         }
-        else /* granulepos is set, validly. Use it, and force a flush to
-                account for shortened blocks (vcut) when appropriate */
+        /* Don't know about granulepos for speex, will just assume the original 
+           was appropriate. Not sure about the flushing?? */
+        else if (state->oggtype == VCEDIT_IS_SPEEX)
         {
-            if(granpos > op.granulepos)
-            {
-                granpos = op.granulepos;
-                ogg_stream_packetin(&streamout, &op);
-                needflush=1;
-            }
-            else
-            {
-                ogg_stream_packetin(&streamout, &op);
-                needout=1;
-            }
+            ogg_stream_packetin(&streamout, &op);
+            needout=1;
         }
     }
 
@@ -492,10 +609,7 @@ int vcedit_write(vcedit_state *state, void *out)
 
 cleanup:
     ogg_stream_clear(&streamout);
-
-    /* We don't ogg_packet_clear() this, because the memory was allocated in
-       _commentheader_out(), so we mirror that here */
-    _ogg_free(header_comments.packet);
+    ogg_packet_clear(&header_comments);
 
     free(state->mainbuf);
     free(state->bookbuf);
